Doc

Enum Doc 

pub enum Doc {
    Nil,
    Text(String),
    Line,
    HardLine,
    Concat(Vec<Doc>),
    Nest(i32, Box<Doc>),
    Group(Box<Doc>),
}
Wadler-Lindig pretty-printing combinators.

A Doc describes a document that can be rendered at a given line width. Group(d) attempts to render d on a single line; if it doesn’t fit within the remaining width the group “breaks” and any Line inside becomes a newline followed by the current indentation.

Variants



Nil



Text(String)



Line

Soft line: a space when the enclosing group is flat, a newline + indentation when it is broken.



HardLine

Hard line: always a newline + indentation regardless of group mode.



Concat(Vec<Doc>)



Nest(i32, Box<Doc>)

Increase indentation for the inner document by n spaces.



Group(Box<Doc>)

Try to render the inner document flat; break if it exceeds the width.

Implementations

Source

impl Doc

pub fn nil() -> Self

pub fn text(s: impl Into<String>) -> Self

pub fn concat(docs: Vec<Doc>) -> Self

pub fn nest(indent: i32, doc: Doc) -> Self

pub fn group(doc: Doc) -> Self