min_error_for_token

Function min_error_for_token 

pub fn min_error_for_token(kind: SyntaxKind, tok: SyntaxKind) -> isize
Returns the minimum error cost that kind must incur when tok is the current token. 0 means the token is reachable (or the rule is nullable); positive means the rule cannot make progress without at least that much error cost.