FatToken

Struct FatToken 

pub struct FatToken<T: TokenTrait> {
    pub kind: T,
    pub range: Range<usize>,
    /* private fields */
}

Fields

kind: Trange: Range<usize>

Implementations

Source

impl<T: TokenTrait> FatToken<T>

pub fn new(kind: T, range: Range<usize>, text: String) -> Self

pub fn text(&self) -> &str

pub fn old_kind(&self) -> Option<Fingerprint>

pub fn set_old_kind(&mut self, kind: Option<Fingerprint>)

pub fn old_depth(&self) -> Option<u8>

pub fn set_old_depth(&mut self, depth: Option<u8>)

pub fn to_prev_token(&self, current_depth: u8) -> PrevToken

pub fn extend_to(&mut self, end: usize, text: String)

Extend this token’s span and text to cover up to end. Used to merge consecutive lexer error tokens into one.