pub struct PrevParseInfo {
pub tokens: Vec<PrevToken>,
pub had_errors: bool,
}Expand description
Information from a previous parse needed for incremental re-parsing.
Fields
tokens: Vec<PrevToken>had_errors: boolWhether the previous parse produced any errors. When true, stored bracket depths are not used for conflict classification (they may be misleading due to error-recovery changing the grammar context), so fingerprint conflicts are treated as free-pass rather than +50 role conflicts.