pub enum JsonLdVal {
Object(Vec<(String, Range<usize>, Range<usize>, JsonLdVal)>, Range<usize>),
Array(Vec<(JsonLdVal, Range<usize>)>),
Str(String),
Number(String),
Bool(bool),
Null,
Invalid,
}Variants
Object(Vec<(String, Range<usize>, Range<usize>, JsonLdVal)>, Range<usize>)
Object carries its span so we can pass it as the triple span for nodes.
Each member is (key, key_span, val_span, value) where key_span is
the byte range of the key string token and val_span is the byte range
of the value token/node in the source, enabling accurate predicate and
object source-mapping.
Array(Vec<(JsonLdVal, Range<usize>)>)
Str(String)
Number(String)
Bool(bool)
Null
Invalid
Implementations
Sourceimpl JsonLdVal
impl JsonLdVal
Sourcepub fn get(&self, key: &str) -> Option<&JsonLdVal>
pub fn get(&self, key: &str) -> Option<&JsonLdVal>
Look up a key inside an Object, returning the value or None.